.. module:: enaml.widgets.flow_item

=======================
enaml.widgets.flow_item
=======================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    FlowItem


.. autoclass:: FlowItem
